#!/usr/bin/python
# --------------------------------------------------@RisingSun//Python//1.0//EN
# Project			:	libosip2
# Description		:	Upgrades libosip1 source files to libosip2 source files
# Website			:	<http://osip.atosc.org>
# License			:	GNU General Public License <http://www.gnu.org>
# -----------------------------------------------------------------------------
# Authors			:	Sebastien Pierre                       <seb@type-z.org>
# -----------------------------------------------------------------------------
# Creation date		:	19-Mar-2003
# Last mod.			:	19-Mar-2003
# History			:	
#						19-Mar-2003 First implementation.
# Bugs				:
#						-
# To do				:
#						-

import os, sys, re

USAGE = """
source-upgrade symbols outputdir <file>*

`source-upgrade' reads the symbols translation information from the given
symbols file and then search and replaces them in the give list of files.

The result is then outputted in the given output directory.

The symbols file must have the following format:

old_symbol  -->  new_symbol

spaces are ignored.
"""

SEPARATOR = "-->"

class Symbol:

	def __init__( self, old, new ):
		self.old = re.compile(old, re.MULTILINE|re.LOCALE)
		self.new = new
	
	def replace( self, text ):
		return self.old.sub(self.new, text)

#------------------------------------------------------------------------------
#
#  Main
#
#------------------------------------------------------------------------------

if __name__ == "__main__":

	#We check the arguments
	if len(sys.argv)<4:
		print USAGE
		sys.exit()

	symbols, outputdir = sys.argv[1:3]
	files = sys.argv[3:]

	#We process the symbols, whicch will be added to the symbols_list
	if not os.path.exists(symbols):
		print "Symbols file '%s' does not exists." % (symbols)
		sys.exit()
	symbols_list = []
	symbols_file = open(symbols, "r")
	for line in symbols_file.read().split("\n"):
		index = line.find(SEPARATOR)
		if index!=-1:
			old = line[:index].strip()
			new = line[index+len(SEPARATOR):].strip()
			symbols_list.append(Symbol(old, new))
	symbols_file.close()

	#We make sure that the output dir exists
	if not os.path.exists(outputdir): os.makedirs(outputdir)

	#And we start the processing
	for file in files:
		print "Processing",file
		file_fd = open(file, "r")
		text = file_fd.read()
		file_fd.close()
		for symbol in symbols_list:
			text = symbol.replace(text)
#		dest_path = outputdir+"/"+file
		dest_path = outputdir
		if not os.path.exists(dest_path): os.makedirs(dest_path)
		dest_file = open(outputdir+"/"+file, "w")
		dest_file.write(text)
		dest_file.close()

	# We read the symbols list
	print "end."

# EOF-Linux/ASCII-----------------------------------@RisingSun//Python//1.0//EN

